DHCPKit
=======

This package contains a flexible DHCP server written in Python 3.4+. This is not a simple plug-and-play DHCP server.
Its purpose is to provide a framework for DHCP services. It was written for ISPs to use in provisioning their customers
according to their own business rules. It can be integrated into existing ISP management and provisioning tools.

Currently only the IPv6 version is implemented.

Documentation
-------------

.. image:: http://readthedocs.org/projects/dhcpkit/badge/?version=stable
  :target: http://dhcpkit.readthedocs.org/en/stable/?badge=stable


Build status
------------

.. image:: https://travis-ci.org/sjm-steffann/dhcpkit.svg?branch=master
  :target: https://travis-ci.org/sjm-steffann/dhcpkit

.. image:: https://coveralls.io/repos/sjm-steffann/dhcpkit/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/sjm-steffann/dhcpkit?branch=master


Distribution status
-------------------

.. image:: https://img.shields.io/pypi/v/dhcpkit.svg
  :target: https://pypi.python.org/pypi/dhcpkit

.. image:: https://img.shields.io/pypi/status/dhcpkit.svg
  :target: https://pypi.python.org/pypi/dhcpkit

.. image:: https://img.shields.io/pypi/l/dhcpkit.svg
  :target: https://pypi.python.org/pypi/dhcpkit

.. image:: https://img.shields.io/pypi/pyversions/dhcpkit.svg
  :target: https://pypi.python.org/pypi/dhcpkit

.. image:: https://img.shields.io/pypi/dw/dhcpkit.svg
  :target: https://pypi.python.org/pypi/dhcpkit
